@@ -1,16 +1,31 @@
 package Alien;
 
 use strict;
-use vars qw($VERSION);
-$VERSION = 0.93;
+use warnings;
+
+# ABSTRACT: External libraries wrapped up for your viewing pleasure!
+our $VERSION = '0.94'; # VERSION
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Alien - External libraries wrapped up for your viewing pleasure!
 
+=head1 VERSION
+
+version 0.94
+
 =head1 SYNOPSIS
 
- perldoc Alien;
+ % perldoc Alien
 
 =head1 DESCRIPTION
 
@@ -52,8 +67,9 @@ These are suggestions only, and this module does not provide a
 framework, because the needs of a non-native dependency on CPAN are 
 potentially quite diverse.  That being said, if your library uses a 
 standard build system, like C<autoconf>, C<make> or C<CMake> you should 
-consider using L<Alien::Base> which makes it easy to write Alien modules 
-that work with many common types of package build systems.
+consider using L<Alien::Build> and L<Alien::Base> which makes it easy to 
+write Alien modules that work with many common types of package build 
+systems.
 
 =head1 CAVEATS
 
@@ -75,18 +91,23 @@ installed.
 Many open source libraries use C<autoconf> and other Unix focused tools 
 that may not be easily available to the native (non-Cygwin) windows 
 Perl. L<Alien::MSYS> provides just enough of these tools for C<autoconf> 
-and may be sufficient for some other build tools.  Also, L<Alien::Base> 
-has hooks to detect C<autoconf> and inject L<Alien::MSYS> as a 
-requirement on Windows when it is needed.
+and may be sufficient for some other build tools.  Also, L<Alien::Build> 
+and L<Alien::Base> have hooks to detect C<autoconf> and inject 
+L<Alien::MSYS> as a requirement on Windows when it is needed.
 
 =item MB vs EUMM
 
 The original Alien documentation recommends the use of L<Module::Build> 
 (MB), which at the time was recommended over L<ExtUtils::MakeMaker> 
-(EUMM). Many Alien distributions have been written using MB (including 
-L<Alien::Base>).  I believe this is because it is an easier build system 
-to adapt to the Alien concept.  It should be noted that MB is no 
-longer universally recommended over EUMM.
+(EUMM).  May Alien distributions have been written using MB.  Including 
+the original installer that came with L<Alien::Base>, 
+L<Alien::Base::ModuleBuild>.  I believe this is because it is an easier 
+build system to adapt to the Alien concept.  MB is no longer universally 
+recommended over EUMM, and has been removed from Perl's core, so if you 
+can, this author recommends using EUMM instead.  L<Alien::Build> and 
+L<Alien::Build::MM> provide tools for creating EUMM based Aliens.  
+Another example worth looking at is L<Alien::pkgconf>, which uses EUMM, 
+but isn't based on L<Alien::Base> or L<Alien::Build>.
 
 =back
 
@@ -150,36 +171,29 @@ Be sane.
 
 No support needed.
 
-=head1 AUTHOR
-
-=over 4
-
-=item Arthur Bergman <abergman@fotango.com>
-
-=item Graham Ollis <plicease@cpan.org>
-
-=back
-
-=head1 COPYRIGHT
-
-This program is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
-
-The full text of the license can be found in the
-LICENSE file included with this module.
-
 =head1 SEE ALSO
 
 =over 4
 
+=item L<alienfile>
+
+A specification for probing, building packages for Aliens.
+
+=item L<Alien::Build>
+
+A new installer agnostic Alien builder, intended to replace 
+L<Alien::Base::ModuleBuild>.  See L<Alien::Build::Manual::AlienAuthor> 
+for details on how to create your own L<Alien::Build> based Alien.
+
 =item L<Alien::Base>
 
 An (optional) base class and framework for creating Alien distributions.
 
-=item L<Alien::Base::FAQ>
+=item L<Alien::Build::FAQ>
 
-Frequently Asked Questions for L<Alien::Base>.  Mostly specific to L<Alien::Base>,
-but also addresses some challenges for Alien in general.
+Frequently Asked Questions for L<Alien::Build>.  Mostly specific to 
+L<Alien::Build>, but also addresses some challenges for Alien in 
+general.
 
 =item L<#native on irc.perl.org|http://chat.mibbit.com/#native@irc.perl.org>
 
@@ -193,8 +207,25 @@ versions will be posted there, but general Alien inquires are also welcome.
 
 =back
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Arthur Bergman <abergman@fotango.com>
+
+=item *
+
+Graham Ollis <plicease@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2003 by Arthur Bergman <abergman@fotango.com>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
-
-1;
-__END__
-
